#!/usr/bin/env python
# *********************************************************************
# * Copyright (C) 2013 Luca Baldini (luca.baldini@pi.infn.it)         *
# *                                                                   *
# * For the license terms see the file LICENCE, distributed           *
# * along with this software.                                         *
# *********************************************************************
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.


import os

from __ROOT__ import *
from __logging__ import logger
from E3Canvas import E3Canvas
from E3H1F import E3H1F


class E3RootChain(ROOT.TChain):

    """ Small wrapper around the TChain class.
    """

    def __init__(self, fileList, treeName):
        """ Constructor.
        """
        logger.info('Initializing TChain with tree name %s...' % treeName)
        ROOT.TChain.__init__(self, treeName)
        if isinstance(fileList, str):
            self.FileList = [fileList]
        else:
            self.FileList = fileList
        for filePath in self.FileList:
            logger.info('Adding %s to the chain...' % filePath)
            self.Add(filePath)
        logger.info('Done, %d entries found.' % self.GetEntries())

    def hist1d(self, expression, cut = '',
               xmin = None, xmax = None, xbins = 100, xpad = 0.5, **kwargs):
        """ Create a plot.
        """
        kwargs['XTitle'] = kwargs.get('XTitle', expression)
        kwargs['YTitle'] = kwargs.get('YTitle', 'Entries/bin')
        cname = 'canvas_%s' % expression
        ctitle = expression
        canvas = E3Canvas(cname, ctitle)
        hname = 'hist_%s' % expression
        if xmin is None or xmax is None:
            branchMin = self.GetMinimum(expression)
            branchMax = self.GetMaximum(expression) 
            branchRange = branchMax - branchMin
        if xmin is None:
            xmin = branchMin - xpad*branchRange
        if xmax is None:
            xmax = branchMax + xpad*branchRange
        htitle = expression
        hist = E3H1F(hname, htitle, xbins, xmin, xmax, **kwargs)
        self.Project(hname, expression, cut)
        hist.Draw()
        canvas.Update()
        store(canvas)
        store(hist)
        return canvas, hist



if __name__ == '__main__':
    from __eee__ import DATA_FOLDER
    filePath = os.path.join(DATA_FOLDER, 'sample_coincidences*.root')
    chain = E3RootChain(filePath, 'CoincidenceTuple')
    canvas, hist = chain.hist1d('DeltaNanoseconds')
