#!/usr/bin/env python
# *********************************************************************
# * Copyright (C) 2012 Luca Baldini (luca.baldini@pi.infn.it)         *
# *                                                                   *
# * For the license terms see the file LICENCE, distributed           *
# * along with this software.                                         *
# *********************************************************************
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.


from __ROOT__ import *
from __logging__ import logger, startmsg
from E3RootChain import E3RootChain
from E3H1F import E3H1F


os.environ['PYTHONINSPECT'] = 'True'


if __name__ == '__main__':
    startmsg()
    from optparse import OptionParser
    parser = OptionParser()

    (opts, args) = parser.parse_args()
    if not len(args):
        parser.error('Please provide at least an input file.')

    chain = E3RootChain(args, 'CernTuple')

    canvas, hist = chain.hist1d('Theta', xmin = 0, xmax = 70,
                                XTitle = 'Theta [#circ]')

    canvas, hist = chain.hist1d('Phi', xmin = -180, xmax = 180,
                                XTitle = 'Phi [#circ]')

    canvas, hist = chain.hist1d('DeltaTime', xmin = 0,
                                XTitle = 'Time difference [s]')
    fitFunc = ROOT.TF1('fitFunc', 'expo', 0.01, 2)
    fitFunc.SetLineColor(ROOT.kRed)
    hist.Fit('fitFunc', 'R')
    l = abs(fitFunc.GetParameter(1))
    canvas.annotate(0.35, 0.6, '#lambda = %.1f Hz' % l, color = ROOT.kRed)
    canvas.SetLogy()
    canvas.Update()

    canvas, hist = chain.hist1d('ChiSquare', xmin = 0,
                                XTitle = '#chi^{2}')
    canvas.SetLogy()
    canvas.Update()

    canvas, hist = chain.hist1d('TimeOfFlight', xmin = -10, xmax = 20,
                                XTitle = 'Time of flight [ns]')
    
    canvas, hist = chain.hist1d('TrackLength',
                                XTitle = 'Track length [cm]')
