#!/usr/bin/env python
# *********************************************************************
# * Copyright (C) 2012--2013 Luca Baldini (luca.baldini@pi.infn.it)   *
# *                                                                   *
# * For the license terms see the file LICENCE, distributed           *
# * along with this software.                                         *
# *********************************************************************
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.


from E3TextInputFile import E3TextInputFile
from E3TextNtuple import E3TextNtuple
from E3CernNtuple import E3CernNtuple
from __logging__ import logger, startmsg


def process(inputFilePath, outputFilePath = None):
    """ Process the text file and convert it to a ROOT tuple.
    """
    logger.info('Determining ntuple type...')
    dataFile = E3TextInputFile(inputFilePath)
    if dataFile.isCernNtuple():
        dataFile.close()
        logger.info('File looks like a cern ntuple.')
        dataFile = E3CernNtuple(inputFilePath)
    elif dataFile.isTextNtuple():
        dataFile.close()
        logger.info('File looks like a text ntuple.')
        dataFile = E3TextNtuple(inputFilePath)
    else:
        abort('Could not detect ntuple type.')
    dataFile.writeRootTuple(outputFilePath)


if __name__ == '__main__':
    startmsg()
    from optparse import OptionParser
    parser = OptionParser()
    (opts, args) = parser.parse_args()
    if not len(args):
        parser.error('Please provide at least an input file.')
    for filePath in args:
        process(filePath, None)

