/*
  Copyright (C) 2012--2013 Luca Baldini (luca.baldini@pi.infn.it)

  For the license terms see the file LICENSE, distributed along with this
  software.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 3 of the License, or (at your option) any later
  version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#ifndef E3_H
#define E3_H


#include <stdint.h>


namespace E3 {

  /// \brief Typedef for a generic marker data field.
  typedef uint32_t Marker_t;
  
  /// \brief Typedef for a generic version number data field.
  typedef uint32_t Version_t;

  /// \brief Typdedef for the station Id data field.
  typedef uint32_t Station_t;

  /// \brief Typedef for the run Id data field.
  typedef uint32_t Run_t;

  /// \brief Typedef for the run name length data field.
  typedef uint16_t RunNameLength_t;

  /// \brief Typedef for the trigger mask data field.
  typedef int32_t TriggerMask_t;

  /// \brief Typedef for the nino map data field.
  typedef uint32_t NinoMap_t;

  /// \brief Typedef for the unix time data field.
  typedef int64_t UnixTime_t;

  /// \brief Typedef for a generic digi word.
  typedef uint32_t DigiWord_t;

  /// \brief Typedef for an RPC channel (default 0--24).
  typedef unsigned short int Channel_t;

  /// \brief Typedef for a telescope plane (default 0--2)
  typedef unsigned short int Plane_t;
 
  /// \brief Typedef for a plane end (positive or negative).
  typedef unsigned short int End_t;

  /// \brief Typedef for a board Id (default 0--1)
  typedef unsigned short int Board_t;

  /// \brief Typedef for a TDC Id (default 0--3)
  typedef unsigned short int Tdc_t;

  /// \brief Typedef for a nino Id.
  typedef unsigned short int Nino_t;

  /// \brief Typedef for an event Id.
  typedef unsigned long int Event_t;

  /// \brief Typedef for a trigger Id;
  typedef unsigned long int Trigger_t;


  /// \brief Definition of the static constants for accessing and looping over
  /// the telescope planes.
  static const Plane_t kNumPlanes = 3;
  static const Plane_t kTopPlane = 0;
  static const Plane_t kMidPlane = 1;
  static const Plane_t kBotPlane = 2;
  static const Plane_t kInvalidPlane = 255;

  /// \brief Definition of the static constants for accessing the plane ends.
  static const End_t kNumEnds = 2;
  static const End_t kPosEnd = 0;
  static const End_t kNegEnd = 1;
}

#endif
