/*
  Copyright (C) 2012 Luca Baldini (luca.baldini@pi.infn.it)

  For the license terms see the file LICENSE, distributed along with this
  software.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 3 of the License, or (at your option) any later
  version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#include "E3AncillaryDataFile.h"


E3AncillaryDataFile::E3AncillaryDataFile() :
  E3BinaryInputFile()
{}



E3AncillaryDataFile::E3AncillaryDataFile(const char* filePath) :
  E3BinaryInputFile(filePath)
{}


E3AncillaryRecord E3AncillaryDataFile::next()
{
  long long seconds;
  read((char*)&seconds, sizeof(long long));
  int recordType;
  read((char*)&recordType, sizeof(int));
  switch (recordType) {
  case DAQ:
    type_eee_daq_record daq;
    read((char*)&daq, sizeof(type_eee_daq_record));
    return E3AncillaryRecord("DAQ", seconds);
  case TRG:
    type_eee_trg_record trg;
    read((char*)&trg, sizeof(type_eee_trg_record));
    return E3AncillaryRecord("TRG", seconds);
  case ENV:
    /// \todo The 6 is hardcoded, here. Need to find a good place for
    /// a global declaration.
    type_eee_env_record env[6];
    read((char*)&env, 6*sizeof(type_eee_trg_record));
    return E3AncillaryRecord("ENV", seconds);
  case GPS:
    type_eee_gps_record gps;
    read((char*)&gps, sizeof(type_eee_gps_record));
    return E3GpsRecord(seconds, gps);
  default:
    return E3AncillaryRecord();
  }
}
