/*
  Copyright (C) 2012 Luca Baldini (luca.baldini@pi.infn.it)

  For the license terms see the file LICENSE, distributed along with this
  software.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 3 of the License, or (at your option) any later
  version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#ifndef E3AncillaryRecord_H
#define E3AncillaryRecord_H

#include <stdio.h>
#include <iostream>
#include <string>
#include <cstring>

#include "E3.h"


enum AncillaryMarker {
  DAQ,
  TRG,
  ENV,
  GPS
};


/*! \brief A whole bunch of typedef struct used on the DAQ side to write the
  binary ancillary file.

  \todo We might want to think twice whether this is really the best way
  to go. At the very least we want to move this part in a separate file to
  make mainteniance easier.
*/

typedef struct eee_daq_record
{
  char status[20];
  char name[128];
  char data_path[100];
  int file_number;
  int fatal_error;
  int write;
  int stop_rq;
  long long start_time;
  long long last_monitor;	
  int sys_info_lock;
  unsigned long max_evt;
  unsigned long evt_num;
  long int file_size;
  FILE *new_format_file;
  FILE *bin_status_file;
  FILE *bin_data_file;
  FILE *arch_file;
} type_eee_daq_record;


typedef struct eee_trg_record
{
  char type[20];
  int itype;
  float rate;
} type_eee_trg_record;


typedef struct eee_env_record
{
  short adt_configured;
  short hv_configured;
  short hv_enabled;
  short io_configured;
  short nino_status;
  float hv_value;
  float pressure;
  float temperature;
  float humidity;
} type_eee_env_record;


typedef struct eee_gps_record
{
  char gpgga_str[128];
  char gprmc_str[128];
  int quality;
  float utc_date;
  float	utc_time;
  float latitude;
  float	longitude;
  char lat_hem;
  char lon_hem;
} type_eee_gps_record;



/*! \class E3AncillaryRecord
  \brief 
*/

class E3AncillaryRecord
{
 public:
  /// \brief Empty constructor.
  E3AncillaryRecord();
  
  /// \brief Default constructor.
  E3AncillaryRecord(std::string type, E3::UnixTime_t unixTime);

  /// \brief Destructor.
  ~E3AncillaryRecord() {}
  
  /// \type Access the m_type class member.
  inline std::string type() const { return m_type; }

  /// \brief Access the m_unixTime class member.
  inline E3::UnixTime_t unixTime() const { return m_unixTime; }

  /// \brief Standard output.
  std::ostream& fillStream(std::ostream& os) const;

  /// \brief Standard output.
  friend std::ostream& operator<<(std::ostream& os, const E3AncillaryRecord& r)
  { return r.fillStream(os); }

 protected:
  /// \brief The record type.
  std::string m_type;

  /// \brief The UNIX time from the host pc running the DAQ.
  E3::UnixTime_t m_unixTime;
};

#endif
