/*
  Copyright (C) 2012--2013 Luca Baldini (luca.baldini@pi.infn.it)

  For the license terms see the file LICENSE, distributed along with this
  software.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 3 of the License, or (at your option) any later
  version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#include "E3BinaryInputFile.h"


E3BinaryInputFile::E3BinaryInputFile() :
  m_size(-1)
{}


E3BinaryInputFile::E3BinaryInputFile(const char* filePath) :
  m_size(-1)
{
  open(filePath);
}


E3BinaryInputFile::E3BinaryInputFile(const std::string filePath) :
  m_size(-1)
{
  open(filePath);
}


StatusCode E3BinaryInputFile::open(const std::string filePath)
{
  return open(filePath.c_str());
}


StatusCode E3BinaryInputFile::open(const char* filePath)
{
  LOG(INFO) << "Opening binary input file " << filePath << "...";
  // Open the file and go straight to the end.
  std::ifstream::open(filePath, std::ios::in|std::ios::binary|std::ios::ate);
  if (!is_open()) {
    // Return 1 on error.
    LOG(ERROR) << "Could not open input file.";
    return StatusCode::FAILURE;
  }
  // Keep track of the file size and go back to the beginning.
  m_size = (int)tellg();
  LOG(INFO) << "File open, " << m_size << " bytes ready to be served.";
  seekg(std::ios::beg);
  return StatusCode::SUCCESS;
}


/*
std::istream& E3BinaryInputFile::read(char* s, std::streamsize n)
{
  
  return std::istream::read(s, n);
}
*/
