/*
  Copyright (C) 2013 Luca Baldini (luca.baldini@pi.infn.it)

  For the license terms see the file LICENSE, distributed along with this
  software.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 3 of the License, or (at your option) any later
  version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#ifndef E3Cluster_H
#define E3Cluster_H


#include <vector>
#include <iomanip>

#include "E3.h"
#include "E3Point.h"
#include "E3Hit.h"


/*! \class E3Cluster
  \brief Class describing a cluster in the detector.

*/

class E3Cluster : public E3Point
{
 public:

  /// \brief Default constructor.
  E3Cluster(E3::Plane_t plane);

  /// \brief Destructor.
  ~E3Cluster() {}

  /// \brief 
  void clear();

  /// \brief Return the plane.
  inline E3::Plane_t plane() const { return m_plane; }

  /// \brief 
  inline unsigned int numHits() const { return m_channelVec.size(); }

  /// \brief
  inline double hitTime() const { return m_hitTime; }

  /// \brief 
  void addHit(const E3Hit& hit);

  /// \brief Standard output.
  std::ostream& fillStream(std::ostream& os) const;

  /// \brief Standard output.
  friend std::ostream& operator<<(std::ostream& os, const E3Cluster& c)
  { return c.fillStream(os); }

 private:
  
  /// \brief The identifier of the RPC plane.
  E3::Plane_t m_plane;

  /// \brief The list of channels in the cluster.
  std::vector<E3::Channel_t> m_channelVec;

  /// \brief The average hit time.
  double m_hitTime;
};


typedef std::vector<E3Cluster> E3ClusterVec;

typedef E3ClusterVec::const_iterator E3ClusterVecIter;

#endif
