/*
  Copyright (C) 2012 Luca Baldini (luca.baldini@pi.infn.it)

  For the license terms see the file LICENSE, distributed along with this
  software.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 3 of the License, or (at your option) any later
  version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#include "E3CoincidenceList.h"


E3CoincidenceList::E3CoincidenceList()
{
  clear();
}


void E3CoincidenceList::fill(E3Coincidence coincidence)
{
  push_back(coincidence);
}


void E3CoincidenceList::fill(E3BaseEvent first, E3BaseEvent second)
{
  fill(E3Coincidence(first, second));
}


StatusCode E3CoincidenceList::write(const char* filePath)
{
  LOG(INFO) << "Writing coincidence list to " << filePath << "...";
  E3CoincidenceNtuple tuple;
  if (tuple.open(filePath)) return(StatusCode::FAILURE);
  LOG(INFO) << "Writing ntuple rows...";
  for (E3CoincidenceList::const_iterator c = begin(); c != end(); c++) {
    tuple.writeRow(*c);
  }
  LOG(INFO) << "Done.";
  return StatusCode::SUCCESS;
} 


StatusCode E3CoincidenceList::write(const std::string filePath)
{
  return write(filePath.c_str());
}


std::ostream& E3CoincidenceList::fillStream(std::ostream& os, unsigned n) const
{
  for (E3CoincidenceList::const_iterator c = begin(); c != end(); c++) {
    unsigned offset = c - begin();
    os << *c;
    if (c < end() - 1) os << std::endl;
    if (offset >= n - 1 && offset < (size() - n)) {
      c += size() - 2*n;
      if (size() != 2*n) os << "..." << std::endl;
    }
  }
  return os;
}
