/*
  Copyright (C) 2012 Luca Baldini (luca.baldini@pi.infn.it)

  For the license terms see the file LICENSE, distributed along with this
  software.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 3 of the License, or (at your option) any later
  version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#ifndef E3CoincidenceList_H
#define E3CoincidenceList_H

#include <vector>
#include <fstream>

#include "E3Coincidence.h"
#include "E3MessageLogger.h"
#include "E3CoincidenceNtuple.h"
#include "E3StatusCode.h"


/*! \class E3CoincidenceList
  \brief Class describing a list of coincidences.

  \todo Apparently inheriting from stl classes is a big no-no, as they do no
  provide virtual destructors. We should investigate that is some more
  details and possibly use composition instead of inheritance (also look at
  free functions).
*/

class E3CoincidenceList : public std::vector<E3Coincidence>
{
 public:
  /// \brief Default constructor.
  E3CoincidenceList();

  /// \brief Destructor.
  ~E3CoincidenceList() {}

  /// \brief Add a coincidence to the current list.
  void fill(E3Coincidence coincidence);

  /// \brief Add a pair of events to the current list.
  void fill(E3BaseEvent first, E3BaseEvent second);

  /// \brief Write the list to a text file.
  StatusCode write(const char* filePath);

  /// \brief Write the list to a text file.
  StatusCode write(const std::string filePath);

  /// \brief Standard output.
  std::ostream& fillStream(std::ostream& os, unsigned n = 3) const;

  /// \brief Standard output.
  friend std::ostream& operator<<(std::ostream& os, const E3CoincidenceList& l)
  { return l.fillStream(os); }

 private:

};

#endif
