/*
  Copyright (C) 2012--2013 Luca Baldini (luca.baldini@pi.infn.it)

  For the license terms see the file LICENSE, distributed along with this
  software.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 3 of the License, or (at your option) any later
  version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#ifndef E3Event_H
#define E3Event_H

#include <iostream>
#include <fstream>

#include "E3.h"
#include "E3Hit.h"
#include "E3Cluster.h"
#include "E3Track.h"
#include "E3DigiEvent.h"
#include "E3TelescopeConfiguration.h"
#include "E3FittingTool.h"


class E3Event : public E3DigiEvent
{
 public:
  /// \brief Default constructor.
  E3Event();

  /// \brief Alternative constructor passing along the seconds field.
  E3Event(E3::UnixTime_t unixTime);

  /// \brief Destructor.
  ~E3Event() {}

  /// \brief Initialize the event.
  void clear();

  /// \brief Run the end-to-end event reconstruction.
  StatusCode reconstruct(const E3TelescopeConfiguration& config);

  /// \brief Return the number of hits in a given plane.
  unsigned short numHits(E3::Plane_t plane) const;

  /// \brief Return the total number of hits.
  unsigned short numHits() const;

  /// \brief Return the number of clusters in a given plane.
  unsigned short numClusters(E3::Plane_t plane) const;

  /// \brief Return the total number of clusters.
  unsigned short numClusters() const;

  /// \brief Return the number of tracks.
  unsigned short numTracks() const;

  /// \brief Return the best track if it exists, a dummy "empty" track
  /// otherwise.
  E3Track bestTrack() const;

  /// \bried Standard output.
  std::ostream& fillStream(std::ostream& os) const;

  /// \brief Standard output.
  friend std::ostream& operator<<(std::ostream& os, const E3Event& e)
  { return e.fillStream(os); }

 private:

  /// \brief The vector of hits.
  E3HitVec m_hitVec[3];

  /// \brief The vector of clusters.
  E3ClusterVec m_clusterVec[3];

  /// \brief The vector of reconstructed tracks.
  E3TrackVec m_trackVec;

  /// \brief Find the hits in the event.
  StatusCode findHits(const E3TelescopeConfiguration& configuration);

  /// \brief Run the clustering stage.
  StatusCode findClusters();

  /// \brief Fit the track candidates.
  StatusCode fitTracks();
};

#endif
