/*
  Copyright (C) 2012--2013 Luca Baldini (luca.baldini@pi.infn.it)

  For the license terms see the file LICENSE, distributed along with this
  software.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 3 of the License, or (at your option) any later
  version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#include "E3GpsRecord.h"


long long datetime2seconds(int year, int month, int day,
                           int hour = 0, int min = 0, int sec = 0)
{
  struct tm timestruct = { 0 };
  timestruct.tm_sec   = sec;
  timestruct.tm_min   = min;
  timestruct.tm_hour  = hour;
  timestruct.tm_mday  = day;
  timestruct.tm_mon   = month - 1;
  timestruct.tm_year  = year - 1900;
  timestruct.tm_isdst = -1;
  return mktime(&timestruct);
}


static const long long kTimeOffset = datetime2seconds(2007, 1, 1);



E3GpsRecord::E3GpsRecord(E3::UnixTime_t unixTime, type_eee_gps_record data) :
  E3AncillaryRecord("GPS", unixTime)
{
  strcpy(m_gpgga, data.gpgga_str);
  strcpy(m_gprmc, data.gprmc_str);
  m_quality = data.quality;
  m_utcDate = data.utc_date;
  m_utcTime = data.utc_time;
  m_latitude = data.latitude;
  m_longitude = data.longitude;
  m_latHem = data.lat_hem;
  m_lonHem = data.lon_hem;
  int day = int(m_utcDate)/10000;
  int month = (int(m_utcDate) - day*10000)/100;
  int year = 2000 + int(m_utcDate) - day*10000 - month*100;
  int hour = int(m_utcTime)/10000;
  int min = (int(m_utcTime) - hour*10000)/100;
  int sec = int(m_utcTime) - hour*10000 - min*100;
  long long seconds = datetime2seconds(year, month, day, hour, min, sec) - 
    kTimeOffset;
  /// @todo Need to understand how we want to parse the ns, here.
  /// What is the rest of the utcTime field in the GPS message?
  long nanoseconds = 0;
  m_timestamp = E3Timestamp(seconds, nanoseconds);
}


std::ostream& E3GpsRecord::fillStream(std::ostream& os) const
{
  os << m_type << " record: UNIX time = " << m_unixTime
     << ", quality = " << m_quality
     << ", date = " << std::setprecision(15) << m_utcDate
     << ", time = " << std::setprecision(15) << m_utcTime
     << ", timestamp = " << timestamp() << ".";
  return os;
}
