/*
  Copyright (C) 2012 Luca Baldini (luca.baldini@pi.infn.it)

  For the license terms see the file LICENSE, distributed along with this
  software.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 3 of the License, or (at your option) any later
  version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#ifndef E3RandomTimeGenerator_H
#define E3RandomTimeGenerator_H

#include <random>

#include "E3RandomGenerator.h"
#include "E3Timestamp.h"


/*! \class E3RandomTimeGenerator
  \brief Random generator simulating a Poisson process in time.
*/

class E3RandomTimeGenerator : E3RandomGenerator
{
 public:
  /// \brief Default constructor.
  E3RandomTimeGenerator(double rate, int seed);

  /// \brief Additional constructor setting the time offset..
  E3RandomTimeGenerator(double rate, double startTime, int seed);

  /// \brief Destructor.
  ~E3RandomTimeGenerator() {}

  /// \brief Get the next time in the sequence.
  double time();

  /// \brief Get the next timestamp in the sequence.
  E3Timestamp timestamp();

 private:
  /// \brief The Underlying didtribution for the time differences.
  std::exponential_distribution<double> m_distribution;

  /// \brief Class member to keep track of the last time extracted.
  ///
  /// (Remember, we extract the *time difference* from an exponential
  /// distribution).
  double m_previousTime;
};

#endif
