/*
  Copyright (C) 2012--2013 Luca Baldini (luca.baldini@pi.infn.it)

  For the license terms see the file LICENSE, distributed along with this
  software.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 3 of the License, or (at your option) any later
  version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#include "E3RawDataFile.h"


E3RawDataFile::E3RawDataFile() :
  E3BinaryInputFile()
{}


E3RawDataFile::E3RawDataFile(const char* filePath) :
  E3BinaryInputFile(filePath)
{}


E3RunInfo E3RawDataFile::parseHeader()
{
  LOG(INFO) << "Parsing file header...";
  E3::Marker_t marker;
  E3::Version_t versionNumber;
  E3::Station_t stationId;
  E3::Run_t runId;
  E3::RunNameLength_t runNameLength;
  E3::TriggerMask_t triggerMask;
  E3::NinoMap_t ninoMapPayload;
  E3::UnixTime_t unixTime;
  type_eee_gps_record gpsPayload;
  read((char*)&marker, sizeof(marker));
  if (marker != RawDataWords::HEADER_BEGIN) {
    LOG(ERROR) << "Giving up on header begin marker (expected " << std::hex
               << std::showbase << RawDataWords::HEADER_BEGIN << ", found "
               << marker << ").";
    exit(1);
  }
  read((char*)&versionNumber, sizeof(versionNumber));
  LOG(INFO) << "Version number " << versionNumber << " found.";
  read((char*)&stationId, sizeof(stationId));
  read((char*)&runId, sizeof(runId));
  read((char*)&runNameLength, sizeof(runNameLength));
  char runName[runNameLength];
  read((char*)&runName, runNameLength);
  read((char*)&triggerMask, sizeof(triggerMask));
  read((char*)&ninoMapPayload, sizeof(ninoMapPayload));
  E3NinoMap ninoMap(ninoMapPayload);
  read((char*)&unixTime, sizeof(unixTime));
  read((char*)&gpsPayload, sizeof(type_eee_gps_record));
  E3GpsRecord startRunGpsRecord(unixTime, gpsPayload);
  read((char*)&marker, sizeof(marker));
  if (marker != RawDataWords::HEADER_END) {
    LOG(ERROR) << "Giving up on header end marker (expected " << std::hex
               << std::showbase << RawDataWords::HEADER_END << ", found "
               << marker << ").";
    exit(1);
  }
  LOG(INFO) << "Event header successfully processed.";
  E3RunInfo runInfo(versionNumber, stationId, runId, runName, triggerMask,
                    ninoMap, startRunGpsRecord);
  LOG(INFO) << "Full dump of run info following...\n" << runInfo;
  return runInfo;
}


E3Event E3RawDataFile::next()
{
  E3::UnixTime_t unixTime;
  E3::DigiWord_t word;
  read((char*)&unixTime, sizeof(unixTime));
  E3Event event(unixTime);
  unsigned int numWords[2];
  read((char*)&numWords, 2*sizeof(word));
  for (unsigned int i = 0; i < numWords[0] + numWords[1]; i++) {
    read((char*)&word, sizeof(word));
    event.addDigiWord(word);
  }
  return event;
}
