/*
  Copyright (C) 2012 Luca Baldini (luca.baldini@pi.infn.it)

  For the license terms see the file LICENSE, distributed along with this
  software.

  This program is free software; you can redistribute it and/or modify it under
  the terms of the GNU General Public License as published by the Free Software
  Foundation; either version 3 of the License, or (at your option) any later
  version.
  
  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/

#include <vector>

#include "E3Track.h"
#include "E3Point.h"
#include "E3FittingTool.h"

// 'Best track #chi^{2}': '3.41', 'Number of track candidates': 1, 'Best track #phi': '-137.86', 'Best track #theta': '27.95'
// 20.00 -53.28 142.00 35.00 -37.05 97.00 55.00 -21.60 53.00


int main () {
  std::vector<E3Point> hitList;
  hitList.push_back(E3Point(20.00, -53.28, 142.00));
  hitList.push_back(E3Point(35.00, -37.05, 97.00));
  hitList.push_back(E3Point(55.00, -21.60, 53.00));

  std::cout << "List of hits:" << std::endl;
  for (std::vector<E3Point>::const_iterator p = hitList.begin();
       p != hitList.end(); p++) {
    std::cout << *p << std::endl;
  }

  std::cout << "Running fitting tool..." << std::endl;
  E3FittingTool fitTool;
  std::cout << "Status code: " << fitTool.run(hitList) << std::endl;
  E3Track track =  fitTool.track();
  std::cout << track << std::endl;
  double z = 53.;
  E3Point p = track.extrapolate(z);
  std::cout << "Extrapolation at z = " << z << ": " << p << std::endl;
  
  return 0;
}
